/*********************************************************
Project:        State Library Administrative Agency Survey
Program:        SLAA2020_AddFormats
Path:           *insert program path here*
Date Created:   March 2021
Description:    This program adds formats to the SLAA2020 SAS dataset 

Input  file:   	*insert dataset path here*

**********************************************************/

/*Assign libname directory - must be changed*/
libname in "/rtpnfil03/rtpnfil03_vol5/IMLS-SLAA/SLAA/Task 2 Data Coll-Process-Analysis/Y4 2020 Collection/DataProcessing/Deliverables";

options fmtsearch=(in.formats_slaa2020);

/*Create formats*/
PROC FORMAT library=in.formats_slaa2020;
VALUE $BRANCH
'L'="Legislative Branch"
'E'="Executive Branch"
;

VALUE $INDAGY
'G'="Governor"
'B'="Board/commission"
'P'='LOGICAL SKIP'
;

VALUE $YN
'Y'="Yes"
'N'="No"
;

VALUE $LARGERAG
'E'="Department of Education"
'C'="Department of Cultural Resources"
'S'="Department of State"
'O'="Other Agency"
'P'='LOGICAL SKIP'
;

VALUE $SKIP
'P'='LOGICAL SKIP'
;

VALUE $NPY
'Y'="Yes"
'N'="No"
'P'="LOGICAL SKIP"
;

VALUE $CDN
'C'="Contract"
'N'="Not provided"
'D'="Directly"
;

VALUE $YNDK
'D'="Don't Know"
'DK'="Don't Know" 
'N'="No" 
'P'='LOGICAL SKIP'
'Y'="Yes"
;

VALUE $RSTATUS
'1'="Respondent, with no imputed data" 
'2'="Respondent, with both reported and imputed data"
;

VALUE $OBEREG
'01'="New England" 
'02'="Mid-East"
'03'="Great Lakes"
'04'="Plains"
'05'="Southeast"
'06'="Southwest"
'07'="Rocky Mountains"
'08'="Far West"
'09'="Outlying Areas"
;

VALUE $MISSING
'M'="Missing" 
;

VALUE $IMPUTED
'GI18'="Imputed, growth using FY18 imputed data"
'GR18'="Imputed, growth using FY18 reported data"
'R'="As reported"
;

run;

/*Apply formats*/
data in.slaa2020_formatted;
	set in.slaa2020;	 
	FORMAT STLANAME $CHAR100.;
	FORMAT PHYSCITY $CHAR50.;
	FORMAT PHYSZIP4 $MISSING.;
	FORMAT MAILCITY $CHAR50.;
	FORMAT MAILZIP4 $MISSING.;
	FORMAT FYSTART MMDDYY10.;
	FORMAT FYEND MMDDYY10.;
	FORMAT BRANCH $BRANCH.;
	FORMAT INDAGY $INDAGY.;
	FORMAT APPBYGOV $NPY.;
	FORMAT APPBYOTH $NPY.;
	FORMAT LARGERAG $LARGERAG.;
	FORMAT OTHAGSP $SKIP.;
	FORMAT PLA_BRCO $NPY.;
	FORMAT PLA_GOV $NPY.;
	FORMAT PLD_OTH $NPY.;
	FORMAT STARCHIV $YN.;
	FORMAT STLEGREF $YN.;
	FORMAT STHSTMUS $YN.;
	FORMAT STRECMNG $YN.;
	FORMAT OTHALLOP $YN.;
	FORMAT OTHALLSP $SKIP.;
	FORMAT STLACONT $YN.;
	FORMAT STLAHOST $YN.;
	FORMAT ACCRLIBA $CDN.;
	FORMAT ACCRLIBB $CDN.;
	FORMAT ACCRLIBC $CDN.;
	FORMAT ACCRLIBD $CDN.;
	FORMAT ACCRLIBE $CDN.;
	FORMAT STAIDSVA $CDN.;
	FORMAT STAIDSVB $CDN.;
	FORMAT STAIDSVC $CDN.;
	FORMAT STAIDSVD $CDN.;
	FORMAT STAIDSVE $CDN.;
	FORMAT CERTLIBA $CDN.;
	FORMAT CERTLIBB $CDN.;
	FORMAT CERTLIBC $CDN.;
	FORMAT CERTLIBD $CDN.;
	FORMAT CERTLIBE $CDN.;
	FORMAT COLLBSTA $CDN.;
	FORMAT COLLBSTB $CDN.;
	FORMAT COLLBSTC $CDN.;
	FORMAT COLLBSTD $CDN.;
	FORMAT COLLBSTE $CDN.;
	FORMAT CNSLTSVA $CDN.;
	FORMAT CNSLTSVB $CDN.;
	FORMAT CNSLTSVC $CDN.;
	FORMAT CNSLTSVD $CDN.;
	FORMAT CNSLTSVE $CDN.;
	FORMAT COOPPURA $CDN.;
	FORMAT COOPPURB $CDN.;
	FORMAT COOPPURC $CDN.;
	FORMAT COOPPURD $CDN.;
	FORMAT COOPPURE $CDN.;
	FORMAT ILLREFA $CDN.;
	FORMAT ILLREFB $CDN.;
	FORMAT ILLREFC $CDN.;
	FORMAT ILLREFD $CDN.;
	FORMAT ILLREFE $CDN.;
	FORMAT LIBLEGA $CDN.;
	FORMAT LIBLEGB $CDN.;
	FORMAT LIBLEGC $CDN.;
	FORMAT LIBLEGD $CDN.;
	FORMAT LIBLEGE $CDN.;
	FORMAT REFREFA $CDN.;
	FORMAT REFREFB $CDN.;
	FORMAT REFREFC $CDN.;
	FORMAT REFREFD $CDN.;
	FORMAT REFREFE $CDN.;
	FORMAT STSTANDA $CDN.;
	FORMAT STSTANDB $CDN.;
	FORMAT STSTANDC $CDN.;
	FORMAT STSTANDD $CDN.;
	FORMAT STSTANDE $CDN.;
	FORMAT SWDIGPRA $CDN.;
	FORMAT SWDIGPRB $CDN.;
	FORMAT SWDIGPRC $CDN.;
	FORMAT SWDIGPRD $CDN.;
	FORMAT SWDIGPRE $CDN.;
	FORMAT STWIDPRA $CDN.;
	FORMAT STWIDPRB $CDN.;
	FORMAT STWIDPRC $CDN.;
	FORMAT STWIDPRD $CDN.;
	FORMAT STWIDPRE $CDN.;
	FORMAT SWVRSA $CDN.;
	FORMAT SWVRSB $CDN.;
	FORMAT SWVRSC $CDN.;
	FORMAT SWVRSD $CDN.;
	FORMAT SWVRSE $CDN.;
	FORMAT UNIVSERA $CDN.;
	FORMAT UNIVSERB $CDN.;
	FORMAT UNIVSERC $CDN.;
	FORMAT UNIVSERD $CDN.;
	FORMAT UNIVSERE $CDN.;
	FORMAT CNTEDPRA $CDN.;
	FORMAT CNTEDPRB $CDN.;
	FORMAT CNTEDPRC $CDN.;
	FORMAT CNTEDPRD $CDN.;
	FORMAT CNTEDPRE $CDN.;
	FORMAT LIBPLANA $CDN.;
	FORMAT LIBPLANB $CDN.;
	FORMAT LIBPLANC $CDN.;
	FORMAT LIBPLAND $CDN.;
	FORMAT LIBPLANE $CDN.;
	FORMAT LITPRSVA $CDN.;
	FORMAT LITPRSVB $CDN.;
	FORMAT LITPRSVC $CDN.;
	FORMAT LITPRSVD $CDN.;
	FORMAT LITPRSVE $CDN.;
	FORMAT PRESERVA $CDN.;
	FORMAT PRESERVB $CDN.;
	FORMAT PRESERVC $CDN.;
	FORMAT PRESERVD $CDN.;
	FORMAT PRESERVE $CDN.;
	FORMAT SUMREADA $CDN.;
	FORMAT SUMREADB $CDN.;
	FORMAT SUMREADC $CDN.;
	FORMAT SUMREADD $CDN.;
	FORMAT SUMREADE $CDN.;
	FORMAT STREADPRA $CDN.;
	FORMAT STREADPRB $CDN.;
	FORMAT STREADPRC $CDN.;
	FORMAT STREADPRD $CDN.;
	FORMAT STREADPRE $CDN.;
	FORMAT CNSLTSV_1_CON $YNDK.;
	FORMAT CNSLTSV_1_DEV $YNDK.;
	FORMAT CNSLTSV_1_CED $YNDK.;
	FORMAT CNSLTSV_1_TC $YNDK.;
	FORMAT CNSLTSV_1_MC $YNDK.;
	FORMAT CNSLTSV_1_ER $YNDK.;
	FORMAT CNSLTSV_1_AL $YNDK.;
	FORMAT CNSLTSV_1_YS $YNDK.;
	FORMAT CNSLTSV_1_OTH $YNDK.;
	FORMAT CNSLTSV_1_OTH_DES $SKIP.;
	FORMAT ACQFEDPG_1_ED $NPY.;
	FORMAT ACQFEDPG_1_AG $NPY.;
	FORMAT ACQFEDPG_1_CC $NPY.;
	FORMAT ACQFEDPG_1_LAB $NPY.;
	FORMAT ACQFEDPG_1_OTH $YNDK.;
	FORMAT ACQFEDPG_1_OTH_DESC $SKIP.;
	FORMAT LITPRSV_1_LA $YNDK.;
	FORMAT LITPRSV_1_NM $YNDK.;
	FORMAT LITPRSV_1_IN $YNDK.;
	FORMAT LITPRSV_1_DG $YNDK.;
	FORMAT LITPRSV_1_FN $YNDK.;
	FORMAT LITPRSV_1_HL $YNDK.;
	FORMAT LITPRSV_1_FM $YNDK.;
	FORMAT STREADPR_1_EC $YNDK.;
	FORMAT STREADPR_1_MC $YNDK.;
	FORMAT STREADPR_1_YA $YNDK.;
	FORMAT STREADPR_1_AD $YNDK.;
	FORMAT STREADPR_1_OA $YNDK.;
	FORMAT GOVDOC_F $IMPUTED.;
	FORMAT STDEPLIB $YN.;
	FORMAT FDDEPLIB $YN.;
	FORMAT REGIONAL $YN.;
	FORMAT SELECTIV $YN.;
	FORMAT LIBVISITS_F $IMPUTED.;
	FORMAT ASF_PUB $YN.;
	FORMAT ASF_AC $YN.;
	FORMAT ASF_SCH $YN.;
	FORMAT ASF_SP $YN.;
	FORMAT ASF_LC $YN.;
	FORMAT FIOTH_IMLSCARES $NPY.;
	FORMAT FIOTH_IMLSOTH $NPY.;
	FORMAT FIOTH_NEH $NPY.;
	FORMAT FIOTH_NHPRC $NPY.;
	FORMAT FIOTH1A $SKIP.;
	FORMAT FIOTH2A $SKIP.;
	FORMAT FIOTH3A $SKIP.;
	FORMAT ELECPLAN $YN.;
	FORMAT ELECOPER $YN.;
	FORMAT ELECBIBL $YN.;
	FORMAT ELECTEXT $YN.;
	FORMAT DIG_STLA $YN.;
	FORMAT DIG_AG $YN.;
	FORMAT DIG_LIB $YN.;
	FORMAT NETTRSTF $YN.;
	FORMAT NETTRCUS $YN.;
	FORMAT NETSUB $YN.;
	FORMAT NETEQUIP $YN.;
	FORMAT NETMOUNT $YN.;
	FORMAT NETGOPH $YN.;
	FORMAT PUBSWDBL $YN.;
	FORMAT ACSWDBL $YN.;
	FORMAT SCHSWDBL $YN.;
	FORMAT SPCSWDBL $YN.;
	FORMAT LCSWDBL $YN.;
	FORMAT OTHSWDBL $YN.;
	FORMAT REMOTEAC $YN.;
	FORMAT ACCWBCAT $YN.;
	FORMAT ACCOTH $YN.;
	FORMAT OTHACCSP $SKIP.;
	FORMAT ERATEAPP $YN.;
	FORMAT ADMLIBSYSA $CDN.;
	FORMAT ADMLIBSYSB $CDN.;
	FORMAT ADMLIBSYSC $CDN.;
	FORMAT ADMLIBSYSD $CDN.;
	FORMAT ADMLIBSYSE $CDN.;
	FORMAT ACQFEDPGA $CDN.;
	FORMAT ACQFEDPGB $CDN.;
	FORMAT ACQFEDPGC $CDN.;
	FORMAT ACQFEDPGD $CDN.;
	FORMAT ACQFEDPGE $CDN.;
	FORMAT STRESSHA $CDN.;
	FORMAT STRESSHB $CDN.;
	FORMAT STRESSHC $CDN.;
	FORMAT STRESSHD $CDN.;
	FORMAT STRESSHE $CDN.;
	FORMAT LSTASTGRA $CDN.;
	FORMAT LSTASTGRB $CDN.;
	FORMAT LSTASTGRC $CDN.;
	FORMAT LSTASTGRD $CDN.;
	FORMAT LSTASTGRE $CDN.;
	FORMAT LSTASTSVA $CDN.;
	FORMAT LSTASTSVB $CDN.;
	FORMAT LSTASTSVC $CDN.;
	FORMAT LSTASTSVD $CDN.;
	FORMAT LSTASTSVE $CDN.;
	FORMAT OBEREGION $OBEREG.;
	FORMAT RSTATUS $RSTATUS.;
run;

proc format library = in.formats_slaa2020
	cntlout = in.formats_slaa2020;
run;

proc contents data=in.slaa2020_formatted varnum;run;